summaryrefslogtreecommitdiffstats
path: root/lskat/lskat/namedlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lskat/lskat/namedlg.cpp')
-rw-r--r--lskat/lskat/namedlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/lskat/lskat/namedlg.cpp b/lskat/lskat/namedlg.cpp
index 66296195..8267d4ea 100644
--- a/lskat/lskat/namedlg.cpp
+++ b/lskat/lskat/namedlg.cpp
@@ -19,15 +19,15 @@
#define NAME_MAX_LEN 12
/*
* Constructs a NameDlg which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-NameDlg::NameDlg( TQWidget *tqparent, const char *name,bool /* modal */, WFlags /* fl */ )
+NameDlg::NameDlg( TQWidget *parent, const char *name,bool /* modal */, WFlags /* fl */ )
: KDialogBase( Plain, i18n("Configure Names"), Ok|Cancel, Ok,
- tqparent, name, true,true )
+ parent, name, true,true )
{
TQWidget *page = plainPage();
@@ -19,15 +19,15 @@
#define NAME_MAX_LEN 12
/*
- * Constructs a NameDlg which is a child of 'tqparent', with the
+ * Constructs a NameDlg which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*